.. BTCnDash documentation master file, created by
   sphinx-quickstart on Sun Mar 20 14:08:35 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents:
=========

.. toctree::
   :maxdepth: 2

   self
   installation.rst
   configuration.rst
   customization.rst
   changelog_link.rst
